========================
 Invenio-Base v1.0.0a16
========================

Invenio-Base v1.0.0a16 was released on August 16, 2017.

About
-----

Base package for building the Invenio application.

What's new
----------

- Initial refactoring for Invenio 3 compatible packages.

Installation
------------

   $ pip install invenio-base==1.0.0a16

Documentation
-------------

   https://invenio-base.readthedocs.io/

Happy hacking and thanks for flying Invenio-Base.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-base
|   URL: http://inveniosoftware.org
